@@ -1,6 +1,7 @@
 /*
  * Copyright © 2002 Jonathan Blandford <jrb@gnome.org>
  * Copyright © 2008 Christian Persch
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * Mate-terminal is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -180,7 +181,7 @@ terminal_skey_do_popup (GtkWindow *window,
 		}
 	}
 
-	if (!terminal_util_load_builder_file ("skey-challenge.ui",
+	if (!terminal_util_load_builder_resource (TERMINAL_RESOURCES_PATH_PREFIX G_DIR_SEPARATOR_S "ui/skey-challenge.ui",
 	                                      "skey-dialog", &dialog,
 	                                      "skey-entry", &entry,
 	                                      "text-label", &label,
